@@ -9,7 +9,7 @@ import shutil
 cache_dir = user_cache_dir('pip') + "/roboflow"
 
 class RoboflowOak:
-    def __init__(self, model, version, api_key, confidence=0.2, overlap=0.5, advanced_config={}, rgb=False, depth=False, device=None, device_name="device", blocking=True, legacy=False):
+    def __init__(self, model, version, api_key, confidence=0.2, overlap=0.5, advanced_config={}, rgb=False, depth=False, device=None, device_name="device", blocking=True, legacy=False, api_endpoint="https://api.roboflow.com"):
         self.project = model
         self.version = version
         self.api_key = api_key
@@ -19,6 +19,7 @@ class RoboflowOak:
         self.overlap = overlap
         self.device_name = device_name
         self.dev = device
+        self.api_endpoint = api_endpoint
         self.advanced_config = advanced_config
         self.fast = not len(self.advanced_config.keys()) > 0
         self.sensor_mode = "THE_1080_P"
@@ -43,7 +44,7 @@ class RoboflowOak:
             self.resolution = self.size
             self.class_names = self.model_objects["class_names"]
             self.colors = self.model_objects["colors"]
-            print("Size",self.size,"Resolution",self.resolution)
+            #print("Size",self.size,"Resolution",self.resolution)
         try:
             self.dai_pipe = DepthAIPipeline(self.cache_path+"/roboflow.blob", self.size, self.resolution, self.class_names, rgb, self.colors, self.fast, self.confidence, self.overlap, self.sensor_mode, self.wide_fov, depth, device, legacy)
         except:
@@ -65,7 +66,7 @@ class RoboflowOak:
                         os.path.join(cache_dir, self.project, self.version, "config.txt")):
             return os.path.join(cache_dir, self.project, self.version)
 
-        return download_blob(self.project, self.version, self.api_key, self.dev)
+        return download_blob(self.project, self.version, self.api_key, self.dev, self.api_endpoint)
 
     def detect(self):
         ret = self.dai_pipe.get()
