@@ -3,12 +3,11 @@ import os
 import json
 from pip._internal.utils.appdirs import user_cache_dir
 
-api_endpoint = "https://api.roboflow.com/oak/"
 cache_dir = user_cache_dir('pip') + "/roboflow"
 
-def download_blob(project, version, api_key, device_id):
+def download_blob(project, version, api_key, device_id, api_endpoint):
 
-    endpoint = api_endpoint+project+"/"+version+"?api_key="+api_key+"&device="+device_id
+    endpoint = api_endpoint+"/oak/"+project+"/"+version+"?api_key="+api_key+"&device="+device_id
     api_data = requests.get(endpoint)
 
     if api_data.status_code != 200:
